@@ -768,7 +768,12 @@ class Database(object):
                     else:
                         # retry getting the actual document data
                         op = lambda: self.backend.get_document(docid).get_data()
-                        data = self.retry_if_modified(op, retry_limit)
+                        try:
+                            data = self.retry_if_modified(op, retry_limit)
+                        except DocNotFoundError:
+                            logger.warning(
+                                "Document %d is gone, skipping.", docid)
+                            continue
                         typ, data = loads(data)
                         seen.add(docid)
                         yield self.record_factory(_lookup_schema(typ).from_flat(data),
@@ -1013,16 +1018,11 @@ class Database(object):
                 limit, rset,
                 enq.INCLUDE_QUERY_TERMS,
                 1.0, decider)
-        elif xapian_version == (1, 2, 5):
-            op = lambda: enq.get_eset(
-                limit, rset,
-                enq.INCLUDE_QUERY_TERMS,
-                1.0, decider, -3)
         else:
             op = lambda: enq.get_eset(
                 limit, rset,
                 enq.INCLUDE_QUERY_TERMS,
-                1.0, decider, 0)
+                1.0, decider, -3)
 
         eset = self.retry_if_modified(op, retry_limit)
 
