@@ -43,6 +43,7 @@ interval = namedtuple("interval", "min max")
 alphabet = 'gatc'
 decodemap = dict((k, i) for (i, k) in enumerate(alphabet))
 
+EARTH_RADIUS = 6378100
 
 def encode(latitude, longitude, precision=22, radians=False):
     """Encode the given latitude and longitude into a geoprint that
@@ -179,7 +180,7 @@ def distance(start, end, radians=False):
     c = 2 * atan2(sqrt(a), sqrt(1 - a))
     if radians:
         return c
-    return 6378100 * c
+    return EARTH_RADIUS * c
 
 
 def bearing(start, end, radians=False):
@@ -237,7 +238,7 @@ def neighbors(geoprint, bearing=True):
     results = set()
     precision = len(geoprint)
     lat1, lon1 = decode(geoprint, radians=True)
-    d = size(geoprint) / 6378100 # radius of earth in meters
+    d = size(geoprint) / EARTH_RADIUS
     for b, r in _radials.iteritems():
         lat = asin(sin(lat1) * cos(d) +
                    cos(lat1) * sin(d) * cos(r))
